@@ -54,7 +54,7 @@ class Minimizer:
                 f"c_{org_id}_focal",
                 {f"y_{org_id}": 1},
                 ">",
-                1,
+                0.5,
                 update=True,
             )
 
@@ -68,6 +68,7 @@ class Minimizer:
 
         self.cache_file = cache_file
         if cache_file and os.path.exists(cache_file):
+            logging.info("Loading constraints from cache file: %s", cache_file)
             with open(cache_file, encoding="utf8") as cache_fd:
                 cache = yaml.load(cache_fd, Loader=yaml.CSafeLoader)
             self._load_constraints_from_cache(cache)
